@@ -31,7 +31,7 @@ class VAE(nn.Module):
 
         # Decoder
         self.mu_dec = nn.Linear(z_dim, in_dim)
-        self.logvar_dec = nn.Parameter(torch.ones(1, in_dim) * 0.5)
+        self.logvar_dec = nn.Parameter(torch.rand(in_dim))
 
     def encode(self, x):
         # Standardization
@@ -60,7 +60,6 @@ class VAE(nn.Module):
 
         return p, q
 
-    @staticmethod
     def loss_function(prediction, target):
         """
         Loss function for VAE.
